#!/usr/bin/env bash

rm -rfv __pycache__
rm -rfv data/i18n
rm -rfv locale
rm -v data/po/*/*.old